==> jc-1.4.0.tar.gz: gnu/java/beans/editors/NativeShortEditor.h <==
// public class gnu.java.beans.editors.NativeShortEditor

// class file dependencies
// @dep_class 980cd3e3cec72dae gnu_java_beans_editors_NativeShortEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeShortEditor_H_
#define _JC_gnu_java_beans_editors_NativeShortEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs	_jc_gnu_java_beans_editors_NativeShortEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$refs	_jc_gnu_java_beans_editors_NativeShortEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$nonrefs	_jc_gnu_java_beans_editors_NativeShortEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$object	_jc_gnu_java_beans_editors_NativeShortEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vmethods	_jc_gnu_java_beans_editors_NativeShortEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vtable	_jc_gnu_java_beans_editors_NativeShortEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vtype	_jc_gnu_java_beans_editors_NativeShortEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeShortEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeShortEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *);
extern void _jc_gnu_java_beans_editors_NativeShortEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeShortEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeShortEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeShortEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *);
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeShortEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeShortEditor$vmethods	gnu_java_beans_editors_NativeShortEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeShortEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeShortEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeShortEditor$refs {
    _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs	gnu_java_beans_editors_NativeShortEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeShortEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs	gnu_java_beans_editors_NativeShortEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeShortEditor$object {
	_jc_gnu_java_beans_editors_NativeShortEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeShortEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeShortEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeShortEditor$vtype _jc_gnu_java_beans_editors_NativeShortEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeShortEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeShortEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeShortEditor_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/editors/NativeShortEditor.h <==
// public class gnu.java.beans.editors.NativeShortEditor

// class file dependencies
// @dep_class 980cd3e3cec72dae gnu_java_beans_editors_NativeShortEditor
// @dep_class 5a63ffefcb362768 java_beans_PropertyEditorSupport
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_PropertyEditorSupport

#include "java/beans/PropertyEditorSupport.h"

#ifndef _JC_gnu_java_beans_editors_NativeShortEditor_H_
#define _JC_gnu_java_beans_editors_NativeShortEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs	_jc_gnu_java_beans_editors_NativeShortEditor$sub_refs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs	_jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$refs	_jc_gnu_java_beans_editors_NativeShortEditor$refs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$nonrefs	_jc_gnu_java_beans_editors_NativeShortEditor$nonrefs;
typedef struct _jc_gnu_java_beans_editors_NativeShortEditor$object	_jc_gnu_java_beans_editors_NativeShortEditor$object;

typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vmethods	_jc_gnu_java_beans_editors_NativeShortEditor$vmethods;
typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vtable	_jc_gnu_java_beans_editors_NativeShortEditor$vtable;
typedef const struct _jc_gnu_java_beans_editors_NativeShortEditor$vtype	_jc_gnu_java_beans_editors_NativeShortEditor$vtype;

// Constructors
extern void _jc_gnu_java_beans_editors_NativeShortEditor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_editors_NativeShortEditor$method$getAsText$e78133031f0dd45a(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_editors_NativeShortEditor$method$setAsText$3108622962800f9f(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_editors_NativeShortEditor$method_info$getAsText$e78133031f0dd45a;
extern _jc_method _jc_gnu_java_beans_editors_NativeShortEditor$method_info$setAsText$3108622962800f9f;

// Virtual methods structure
struct _jc_gnu_java_beans_editors_NativeShortEditor$vmethods {
	struct _jc_java_lang_String$object	*(*getAsText$e78133031f0dd45a)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *) _JC_JCNI_ATTR;
	void	(*setAsText$3108622962800f9f)(_jc_env *, struct _jc_gnu_java_beans_editors_NativeShortEditor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_editors_NativeShortEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorSupport$vmethods	java_beans_PropertyEditorSupport;
	_jc_gnu_java_beans_editors_NativeShortEditor$vmethods	gnu_java_beans_editors_NativeShortEditor;
};

// Vtype
struct _jc_gnu_java_beans_editors_NativeShortEditor$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_editors_NativeShortEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeShortEditor$refs {
    _jc_gnu_java_beans_editors_NativeShortEditor$sub_refs	gnu_java_beans_editors_NativeShortEditor;
    _jc_java_beans_PropertyEditorSupport$sub_refs	java_beans_PropertyEditorSupport;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_editors_NativeShortEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorSupport$sub_nonrefs	java_beans_PropertyEditorSupport;
    _jc_gnu_java_beans_editors_NativeShortEditor$sub_nonrefs	gnu_java_beans_editors_NativeShortEditor;
};

// Object instance structure
struct _jc_gnu_java_beans_editors_NativeShortEditor$object {
	_jc_gnu_java_beans_editors_NativeShortEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_editors_NativeShortEditor$vtype	*vtype;
	_jc_gnu_java_beans_editors_NativeShortEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_editors_NativeShortEditor$vtype _jc_gnu_java_beans_editors_NativeShortEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_editors_NativeShortEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_editors_NativeShortEditor$class_object;

#endif	/* _JC_gnu_java_beans_editors_NativeShortEditor_H_ */
